function  input_data  = simulatedDataCellImage( filename )
%CELL256 Describes problem and creates data structure
%   This driver file is an example file to explain
%   how problems are created in the PRwSC toolbox.
% 
%   Input: 
%           filename - Name (string) of the file that contains the data.
%                      The input is assumed to be of the type .mat
%                      containing only one variable named 'pattern'.
%
%   Output:
%           input_data - A matlab structure containing various
%                        information needed in the toolbox like
%                        the problem type, physical parameters,
%                        qualitative constraints and algorithmic
%                        parameters.
% For an explanation of the elements of the created structure,
% we refer to the documentation.

% Get preproccessed data. Right now, the method only returns the data
% itself.

input_data = readDataFromFile(filename);

% Since we don't now at this point which fields the readDataFromFile
% function provides us, we check for neccessary information and provide
% some reasonable choices ourselfes if they are not set yet.

if ~isfield(input_data, 'problem')
    input_data.problem.type    = 'phase';            % 'phase', 'amplitude', 'mixed'
end

if ~isfield(input_data, 'algorithm')
    input_data.algorithm.name       = 'RAAR';        % currently: RAAR, MAP
    input_data.algorithm.parameter  = 'const';     % 'dynamic', 'constant' - we don't fiddle with specifics here
    input_data.algorithm.beta.null  = 0.99;
    input_data.algorithm.beta.max   = 0.55;
    input_data.algorithm.beta.switch = 20;
    input_data.algorithm.beta.value = 0.55;
end

if ~isfield(input_data, 'physicalParameters')
    if strcmp(input_data.problem.type, 'phase')
        input_data.physicalParameters.delta = 1.6e-6;                                                  % decrement of real part of defr. idx
    else
        input_data.physicalParameters.delta  = 0;                                              
    end
    if strcmp(input_data.problem.type, 'amplitude')
        input_data.physicalParameters.beta = 8e-7;                                                   % imag. part of defr. idx
    else
        input_data.physicalParameters.beta   = 0.0;                                                
    end
    input_data.physicalParameters.tau    = 1e-5;                                                    % lateral thickness
    input_data.physicalParameters.lambda = 1e-10;                                                   % Wave length
    input_data.physicalParameters.k      = 2*pi/input_data.physicalParameters.lambda;               % Wave number
    input_data.physicalParameters.P      = input_data.data * input_data.physicalParameters.tau;     % Phase distribution
    input_data.physicalParameters.A      = input_data.data * input_data.physicalParameters.tau;     % Amplitude distribution
    input_data.Psi    = exp(-1i.*input_data.physicalParameters.k....             % Wave function Psi
                         *input_data.physicalParameters.delta.*input_data.physicalParameters.P...
                         -input_data.physicalParameters.k.*input_data.physicalParameters.beta....
                         *input_data.physicalParameters.A);
end

if ~isfield(input_data.problem, 'noise')
    input_data.noise.type = 'poisson';      % poisson or gaussian
    input_data.noise.level = 50;            % poisson: expct. photons/pixel, gaussian: variance
    input_data.noise.error = 1e-2;          % describes the phattening of the set M
end

if ~isfield(input_data.problem, 'propagator')
    input_data.problem.propagator           = 'Fresnel';                   % Fresnel or Fourier
    input_data.problem.Fx                   = 4*1e-3;                      % Fresnel number x-coordinate
    input_data.problem.Fy                   = 4*1e-3;                      % Fresnel number y-coordinate
    input_data.problem.data                 = abs(wavePropagator(input_data, input_data.Psi,1)); % Measurement data are pointwise modulus in fresnel/fourier domain
    input_data.problem.data                 = createNoisyMeasurement(input_data);
    input_data.problem.constraint.name      = 'shearlet thresholding and range';     % shearlet, support, negativity, amplitude
    input_data.problem.constraint.info      = 'smooth hard';               % optional (depends on constraint name). soft / smooth hard
    input_data.problem.constraint.parameter = 'dynamic';                   % dynamic = 1/k right now, const 
    input_data.problem.constraint.gamma0    = 0.001;                       % initial threshold parameter
    input_data.problem.constraint.support   = createSupportIdx(input_data, 0.8, 'box'); % for the cell and box, we would chose R=0.75.
end


end
